@@ -4,5 +4,5 @@ from django.apps import AppConfig
 class Config(AppConfig):
     """Config."""
 
-    name = 'invitations'
-    label = 'invitations'
+    name = "invitations"
+    label = "invitations"
